@@ -40,7 +40,9 @@ def cron(*,
          quick_start: bool = False,
          cron_file: str = "",
          screen_cmd: str = "screen",
+         screen_log: str = "",
          no_screen: bool = True,
+         keep_ld_library_path: bool = False,
          sockname: str = "cron",
          python_exec: str = "",
          detach: bool = False,
@@ -72,7 +74,13 @@ def cron(*,
         cmd = screen_cmd
         if detach:
             cmd += " -d"
+        if screen_log != "":
+            cmd += " -L -Logfile " + screen_log
         cmd += " -m -S " + sockname
+        if keep_ld_library_path and 'LD_LIBRARY_PATH' in os.environ:
+            cmd += " env LD_LIBRARY_PATH='"
+            cmd += os.environ["LD_LIBRARY_PATH"]
+            cmd += "'"
         cmd +=" "+ python_exec + " -m bussilab cron --no-screen"
         cmd +=" --period " + str(period)
         if len(cron_file)>0:
@@ -81,5 +89,7 @@ def cron(*,
             cmd += " --quick-start"
         if max_times is not None:
             cmd += " --max-times " + str(max_times)
-        print(cmd)
-        os.system(cmd)
+        print("cmd:",cmd)
+        ret=os.system(cmd)
+        if ret != 0:
+            raise RuntimeError("Execution of '" + cmd + "' failed. Perhaps '" + screen_cmd + "' command is not available on your system");
